# estival
Calibration and optimization tools for summer

A minimal pip-installable package providing MCMC and support tools for use with the summer2 library 

Based on the AuTuMN calibration module

https://github.com/monash-emu/AuTuMN
